@@ -32,47 +32,34 @@ import sys
 import os
 import traceback
 from functools import partial
+from operator import attrgetter
 from . import api as pg_api
+from . import sys as pg_sys
 
+PythonException = Exception
 class Exception(Exception):
 	'Base PostgreSQL exception class'
 	pass
 
-class PythonMessage(pg_api.Message):
-	"""
-	It's a message, but with __str__ returning the element's entire ancestry.
-	"""
-	ife_ancestor = None
+class LoadError(Exception):
+	'Failed to load a library'
 
-	def __str__(self):
-		# if a snapshot was taken, use it.
-		ss = getattr(self, 'snapshot', None)
-		if ss is None:
-			# the picture might not be accurate, but it will
-			# be better than nothing.
-			ss = self.ife_ancestry_snapshot_text()
+class Disconnection(Exception):
+	'Exception identifying errors that result in disconnection'
 
-		l = [
-			': '.join((x[1], x[2])) for x in ss
-		]
-		this = self.ife_snapshot_text()
-		return this + (os.linesep + os.linesep.join(l) if l else '')
-
-class Warning(PythonMessage, Warning):
+class Warning(pg_api.Message):
 	code = '01000'
-	ife_label = 'WARNING'
-
-	def __str__(self):
-		r = super().__str__()
-		return type(self).__name__ + ': ' + r + os.linesep
+	_e_label = property(attrgetter('__class__.__name__'))
 
 class DriverWarning(Warning):
-	code = ''
+	code = '01-00'
 	source = 'CLIENT'
 class IgnoredClientParameterWarning(DriverWarning):
 	'Warn the user of a valid, but ignored parameter.'
+	code = '01-CP'
 class TypeConversionWarning(DriverWarning):
 	'Report a potential issue with a conversion.'
+	code = '01-TP'
 
 class ClusterWarning(Warning):
 	code = ''
@@ -98,54 +85,54 @@ class NoDataWarning(Warning):
 class NoMoreSetsReturned(NoDataWarning):
 	code = '02001'
 
-class Error(PythonMessage, Exception):
+class Error(pg_api.Message, Exception):
 	'A PostgreSQL Error'
-	ife_label = 'ERROR'
-	code = ""
+	_e_label = 'ERROR'
+	code = ''
+
+	def __str__(self):
+		'Call .sys.errformat(self)'
+		return pg_sys.errformat(self)
 
 	@property
 	def fatal(self):
 		f = self.details.get('severity')
 		return None if f is None else f in ('PANIC', 'FATAL')
 
-	def raise_exception(self, raise_from = None):
-		"""
-		Raise the `Error`, `self`, *after* gettings a snapshot of the ancestry.
-		"""
-		# get the snapshot before raising to get an accurate view of the state
-		self.snapshot = self.ife_ancestry_snapshot_text()
-		if raise_from is None:
-			raise self
-		else:
-			raise self from raise_from
-
 class DriverError(Error):
 	"Errors originating in the driver's implementation."
 	source = 'CLIENT'
-class AuthenticationMethodError(DriverError):
+	code = '--000'
+class AuthenticationMethodError(DriverError, Disconnection):
 	"""
 	Server requested an authentication method that is not supported by the
 	driver.
 	"""
-class InsecurityError(DriverError):
+	code = '--AUT'
+class InsecurityError(DriverError, Disconnection):
 	"""
 	Error signifying a secure channel to a server cannot be established.
 	"""
+	code = '--SEC'
+class ConnectTimeoutError(DriverError, Disconnection):
+	'Client was unable to esablish a connection in the given time'
+	code = '--TOE'
 
 class TypeIOError(DriverError):
 	"""
 	Driver failed to pack or unpack a tuple.
 	"""
+	code = '--TIO'
 class ParameterError(TypeIOError):
-	pass
+	code = '--PIO'
 class ColumnError(TypeIOError):
-	pass
+	code = '--CIO'
 
 class OperationError(DriverError):
 	"""
 	An invalid operation on an interface element.
 	"""
-
+	code = '--OPE'
 ##
 # Exceptions pertinent to cluster initialization and management
 ##
@@ -168,7 +155,7 @@ class TransactionError(Error):
 class SQLNotYetCompleteError(Error):
 	code = '03000'
 
-class ConnectionError(Error):
+class ConnectionError(Error, Disconnection):
 	code = '08000'
 class ConnectionDoesNotExistError(ConnectionError):
 	"""
@@ -181,64 +168,9 @@ class ConnectionFailureError(ConnectionError):
 
 class ClientCannotConnectError(ConnectionError):
 	"""
-	Client was unable to establish a connection to the server
-
-	This is the exception that drivers must raised when a connection could not be
-	established.
+	Client was unable to establish a connection to the server.
 	"""
 	code = '08001'
-	connection_failures = None
-
-	def ife_snapshot_text(self):
-		top = super().ife_snapshot_text()
-		bottom = ""
-		if self.connection_failures:
-			count = 0
-			bottom = 'ATTEMPTS: count of ' + \
-				str(len(self.connection_failures))
-			for x in self.connection_failures:
-				count += 1
-				ssl = (
-					'SSL' if x[0] is True else 'NOSSL' if x[0] is False else "SSL->NOSSL"
-				)
-				bottom += os.linesep + ' ' + str(count) + ': '
-				bottom += str(x[1]) + ' -> (' + ssl + ') resulted in:' + os.linesep + ' '*2
-				fmt_exc = traceback.format_exception_only(type(x[2]), x[2])
-				bottom += (os.linesep + ' '*2).join(''.join(fmt_exc).split(os.linesep))
-			bottom = os.linesep + '--' + os.linesep + bottom.strip() + os.linesep + '--'
-		return top + bottom
-
-	def set_connection_failures(self, failures):
-		"""
-		When the connection cannot be establish, configure the failures to give
-		the user more information about what was attempted.
-
-		Usually, this should contain the exceptions that actually occurred in the
-		process of connecting.
-		"""
-		self.connection_failures = failures
-
-	def failure_due_to(self, exc : ""):
-		"""
-		Return a tuple indicating the amount of "fault" that the given
-		exception had on the failures.
-
-		# one of the two connection failures were due to ServerNotReadyError.
-		>>> err.failure_due_to(ServerNotReadyError)
-		(1, 2)
-		"""
-		if self.connection_failures is None:
-			return None
-		return (
-			count([
-				x for x in self.connection_failures
-				if isinstance(x.exception, exc)
-			]),
-			len(self.connection_failures)
-		)
-
-class ClientConnectTimeoutError(ClientCannotConnectError):
-	'Client was unable to esablish a connection in the given time'
 
 class ConnectionRejectionError(ConnectionError):
 	code = '08004'
@@ -280,7 +212,7 @@ class CardinalityError(Error):
 class TriggeredDataChangeViolation(Error):
 	code = '27000'
 
-class AuthenticationSpecificationError(Error):
+class AuthenticationSpecificationError(Error, Disconnection):
 	code = '28000'
 
 class DPDSEError(Error):
@@ -678,11 +610,11 @@ class OIError(Error):
 	code = '57000'
 class QueryCanceledError(OIError):
 	code = '57014'
-class AdminShutdownError(OIError):
+class AdminShutdownError(OIError, Disconnection):
 	code = '57P01'
-class CrashShutdownError(OIError):
+class CrashShutdownError(OIError, Disconnection):
 	code = '57P02'
-class ServerNotReadyError(OIError):
+class ServerNotReadyError(OIError, Disconnection):
 	'Thrown when a connection is established to a server that is still starting up.'
 	code = '57P03'
 
