@@ -512,6 +512,7 @@ def array_typio(
 				pack_array_elements(data.elements)
 			))
 	else:
+		# signals string formatting
 		pack_an_array = None
 
 	if hasbin_output:
@@ -532,6 +533,7 @@ def array_typio(
 				dimensions = dim
 			)
 	else:
+		# signals string formatting
 		unpack_an_array = None
 
 	return (pack_an_array, unpack_an_array)
@@ -754,8 +756,8 @@ class TypeIO(object, metaclass = ABCMeta):
 
 	def set_encoding(self, value):
 		self.encoding = value.lower().strip()
-		enc = pg_enc_aliases.postgres_to_python.get(self.encoding, value)
-		ci = codecs.lookup(enc)
+		enc = pg_enc_aliases.get_python_name(self.encoding)
+		ci = codecs.lookup(enc or self.encoding)
 		self._encode = ci[0]
 		self._decode = ci[1]
 
