@@ -46,7 +46,7 @@ quote_re = re.compile(r"""(?xu)
 |	(\$(?:[^0-9$]\w*)?\$).*?(?:\1|$)   (?# Dollar quotes $$str$$)
 """)
 
-def split(text, re = quote_re):
+def split(text):
 	"""
 	split the string up by into non-quoted and quoted portions. Zero and even
 	numbered indexes are unquoted portions, while odd indexes are quoted
@@ -66,6 +66,7 @@ def split(text, re = quote_re):
 	to identify the best course of action for the given split.
 	"""
 	lastend = 0
+	re = quote_re
 	scan = re.scanner(text)
 	match = scan.search()
 	while match is not None:
@@ -206,7 +207,7 @@ def split_ident(text, sep = ',', quote = '"', maxsplit = -1):
 
 def split_qname(text, maxsplit = -1):
 	"""
-	Call to pg_str.split_ident() with a '.' sep parameter.
+	Call to .split_ident() with a '.' sep parameter.
 	"""
 	return split_ident(text, maxsplit = maxsplit, sep = '.')
 
@@ -217,7 +218,7 @@ def qname(*args):
 def split_sql(sql, sep = ';'):
 	"""
 	Given SQL, safely split using the given separator.
-	Notably, this yields split text. This should be used instead of
+	Notably, this yields fully split text. This should be used instead of
 	split_sql_str() when quoted sections need be still be isolated.
 
 	>>> list(split_sql('select $$1$$ AS "foo;"; select 2;'))
