@@ -4,6 +4,7 @@
 import unittest
 from ..unittest import TestCaseWithCluster
 import time
+from ..python.contextlib import NoCM
 
 ##
 # Various Adjustments for pg.driver.dbapi20
@@ -108,10 +109,16 @@ class test_dbapi20(TestCaseWithCluster):
 		finally:
 			con.close()
 
+	def connection(self):
+		return NoCM
+
 	def _connect(self):
-		c = self.db.connector()
-		c.connect()
-		return self.driver.Connection(c)
+		host, port = self.cluster.address()
+		return self.driver.connect(
+			user = 'test',
+			host = host,
+			port = port,
+		)
 
 	def test_connect(self):
 		con = self._connect()
@@ -335,6 +342,25 @@ class test_dbapi20(TestCaseWithCluster):
 		# connection.close should raise an Error if called more than once
 		self.assertRaises(self.driver.Error,con.close)
 
+	def test_cursor_close(self):
+		con = self._connect()
+		try:
+			cur = con.cursor()
+			cur.close()
+			# cursor.execute should raise an Error if called after cursor.close
+			# closed
+			self.assertRaises(self.driver.Error,self.executeDDL1,cur)
+			# cursor.executemany should raise an Error if called after connection'
+			# closed.'
+			self.assertRaises(self.driver.Error,cur.executemany,'foo', [])
+
+			self.assertRaises(self.driver.Error,cur.callproc,'generate_series', [1, 10])
+
+			# cursor.close should raise an Error if called more than once
+			self.assertRaises(self.driver.Error,cur.close)
+		finally:
+			con.close()
+
 	def test_execute(self):
 		con = self._connect()
 		try:
@@ -800,13 +826,13 @@ class test_dbapi20(TestCaseWithCluster):
 		d1 = self.driver.Date(2002,12,25)
 		d2 = self.driver.DateFromTicks(time.mktime((2002,12,25,0,0,0,0,0,0)))
 		# Can we assume this? API doesn't specify, but it seems implied
-		# self.assertEqual(str(d1),str(d2))
+		self.assertEqual(str(d1),str(d2))
 
 	def test_Time(self):
 		t1 = self.driver.Time(13,45,30)
 		t2 = self.driver.TimeFromTicks(time.mktime((2001,1,1,13,45,30,0,0,0)))
 		# Can we assume this? API doesn't specify, but it seems implied
-		# self.assertEqual(str(t1),str(t2))
+		self.assertEqual(str(t1),str(t2))
 
 	def test_Timestamp(self):
 		t1 = self.driver.Timestamp(2002,12,25,13,45,30)
@@ -814,7 +840,7 @@ class test_dbapi20(TestCaseWithCluster):
 			time.mktime((2002,12,25,13,45,30,0,0,0))
 		)
 		# Can we assume this? API doesn't specify, but it seems implied
-		# self.assertEqual(str(t1),str(t2))
+		#self.assertEqual(str(t1),str(t2))
 
 	def test_Binary(self):
 		b = self.driver.Binary(b'Something')
